using BPA.SAAS.Manage.Application.Org.Dtos.Organize;
using BPA.SAAS.Manage.Core.Base;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BPA.SAAS.Manage.Application.Org.Interface
{
    public interface IOrganizeService
    {
        Task<PageUtil> QueryOrgPageList(OrgPageInput input);
        Task<List<OrgOutput>> GetOrgList(OrgListInput input);
        Task<bool> AddOrg(OrgAddInput input);
        Task<bool> DeleteOrg(string id);
        Task<bool> UpdateOrg(UpdateOrgInput input);
        Task<dynamic> GetOrgTree();
        Task<Dictionary<string, object>> GetOrgList();
    }
}
